import { PaymentSlipValidator as ParamsPaymentSlipValidatorInterface, ParamsPaymentSlipValidator } from '../contracts';
type ConstructorInterface = Pick<ParamsPaymentSlipValidatorInterface, 'digits'>;
type IsValid = ParamsPaymentSlipValidator;
type ReturnGetDataPaymentSlip = {
    digits: string | undefined;
    bankName: string | null;
    bankCode: string | null;
    price: string | null;
    expirationDate: string | null;
    typeOfPaymentSlip: string | null;
    barCodeOrTypeableLine: string | null;
    segmentPaymentSplip: string | null;
    isValid: boolean;
};
/**
   *
    @class PaymentSlipValidator

    @summary
    Motivation:
      - Testing and capture data payment slip with types bank slip and tax collection..

    Details:
      - It is possible to validate and capture data payment slips (banking) and collection slips, in typeable line formats and barcode numbering.
      - Among the validations are: validation by the issuing bank of the bill; segment type, payment amount; due date.
      - Among the data captured are: payment slip digits; issuing bank code; issuing bank name; payment slip price; expiration date; segment to
        which the payment slip is inserted; if the payment slip is type barcode or typeable lines.

    Limitations:
      - In accordance with FEBRABAN (Brazilian Federation of Banks) regulations: "Layout" Standard for Collection/Receipt Using Bar Codes, version 06,
      for collection-type slips, due dates do not follow a pattern. The issuing bank is responsible for inserting this data in the blocks of free or
      unavailable fields, and, if inserted, it must be have the format YYYYMMDD. As a result, validation of the due date for payment slips does not have
      a standard, so it is not recommended that the validation of a payment slip is verified only by the due date.
    @see https://cmsarquivos.febraban.org.br/Arquivos/documentos/PDF/Layout%20-%20C%C3%B3digo%20de%20Barras%20ATUALIZADO.pdf.
  */
export declare class PaymentSlipValidator {
    private digits;
    private typesOfPaymentSlip;
    private regexLengthDigitsValidator;
    constructor({ digits }: ConstructorInterface);
    private checkIsBankSlipOrTaxCollection;
    private capturePaymentSlipData;
    getData(): ReturnGetDataPaymentSlip;
    /**
     *
     * @param paramsPaymentSlipValidator
     * @argument validByBank: Bank code or bank name can be passed for validation
     * @argument validSegmentType: Used to check which segment the payment slip is inserted in
     * @argument validByPrice: Used to check the value of the payment slip
     * @argument validByDate: Used to check the date of the payment slip
     * @argument validByTypeOfPaymentSlip: Used to check if the payment slip is of the Banking or Collection type
     * @argument validByIfIsBarCodeOrTypeableLine: Used to check if the payment slip is a barcode type or typeable lines
     * @returns boolean
     */
    isValid(paramsPaymentSlipValidator?: IsValid): boolean;
    /**
     *
     * @param deps
     * @returns instance of PaymentSlipValidator
     */
    static init(deps: ConstructorInterface): PaymentSlipValidator;
}
export {};
//# sourceMappingURL=index.d.ts.map