import { PhoneValidator } from '../contracts/phone';
/**
 @param {Object} PhoneValidator
 @returns boolean

 @summary
  Motivation:
    - Phone number test with validations of mobile phone numbers (BR), public utility numbers (BR),
      numbers without area code (BR), international numbers and custom validations with regex patterns.

  Details:
    - Numbering structure of a telephone number:
        CC = Coutry Code;
        NDC = Number Area State Code (National Destination Code);
        N = Number phone;
        +CC NDC N => +55 85 99999-9999
        reference: https://www.itu.int/rec/T-REC-E.164-201011-I/en

    - Validation priority order:
      * If there is paramsPhoneValidator, the following order is parsed:
        1º: If there is param Phone Validator.custom Pattern Phone;
        2º: Whether validation should occur with international phone numbers, based on E.164;
        3º: Whether validation should only occur with mobile phone numbers (BR);
            - If paramsPhoneValidator.onlyMobilePhoneBR is true, there is a condition that
              validation occurs with or without the DDD digits, with paramsPhoneValidator.numberWithoutCodeAreas.
        4º: Whether validation should occur only for public utility numbers;
      * If there is no paramsPhoneValidator or if you have paramsPhoneValidator.numberWithoutCodeAreas},
            validation will occur with standard Brazilian numbers.

    - Rules for telephone numbering in Brazil:
      Cellular Telephony - Initial digit:
        - 9 for Bands A (96 to 99) and B (91 to 94);
        - 8 for Bands D and E;
        - 7 Cellular and Trunking (Nextel);
        - 6 for bands A, B, D and E*;
      Fixed Telephony - Initial digit
        - 2 to 5;
      Public utility numbers:
        - Composed of 3 to 4 numbers, starting with the digit 1.
      reference: https://www.teleco.com.br/num.asp
 */
export declare const phoneValidator: ({ phone, paramsPhoneValidator, }: PhoneValidator) => boolean;
//# sourceMappingURL=index.d.ts.map